..  Titling
    ##++::==~~--''``

.. _`screenshots section`:

Screenshots
===========

Traditional
-----------

.. figure:: ./_static/cloak_of_darkness-screen.png
   :width: 16em

   A recreation of the famous *Cloak of Darkness* Interactive Fiction.

Artistic
--------

.. figure:: ./_static/styling_themes-shot.png
   :width: 16em

   Application of CSS styling and layout.

Technical
---------

.. figure:: ./_static/bottles-shot.png
   :width: 16em

   Example of SVG icons and a Javascript product viewer.
